"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const api_error_1 = require("./api-error");
const MAX_ERROR_LENGTH = 200;
exports.writeResponse = (dataPromise, req, res, next) => {
    return dataPromise
        .then((data) => {
        writeSuccessResponse(req, res, next, data);
    })
        .catch((err) => {
        exports.writeErrorResponse(res, next, err);
    })
        .then(() => dataPromise); // for type checking in contollers
};
const writeSuccessResponse = (req, res, next, data) => {
    const apiResponse = {
        data,
        success: true
    };
    res.json(apiResponse);
};
exports.writeErrorResponse = (res, next, err, status) => {
    const statusCode = status || err && err instanceof api_error_1.ApiError && err.status || 400;
    if (statusCode) {
        res.status(statusCode);
    }
    const apiResponse = {
        success: false,
        message: err.message || err
    };
    if (apiResponse.message && apiResponse.message.length > MAX_ERROR_LENGTH) {
        // tslint:disable-next-line prefer-template
        apiResponse.message = apiResponse.message.substr(0, MAX_ERROR_LENGTH) + '...';
    }
    res.json(apiResponse);
    return null;
};
