"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const user_model_1 = require("./user-model");
const password_token_model_1 = require("./password-token-model");
class AuthRepo {
    findUser(criteria) {
        return user_model_1.UserModel
            .aggregate()
            .match(criteria)
            .addFields({
            id: '$_id'
        })
            .project({
            _id: 0,
            __v: 0
        })
            .exec()
            .then((res) => res[0]);
    }
    getUser(email, social = null) {
        return this.findUser({
            email,
            social
        });
    }
    createUser(user) {
        return user_model_1.UserModel.create({
            fullName: user.fullName,
            email: user.email,
            password: user.password,
            social: user.social,
            admin: false,
            anonymous: user.anonymous
        }).then((userDoc) => ({
            id: userDoc.id,
            fullName: userDoc.fullName,
            email: userDoc.email,
            admin: userDoc.admin,
            social: userDoc.social,
            anonymous: userDoc.anonymous
        }));
    }
    upsertPasswordToken(email, token) {
        return this.findUser({
            email,
            social: null,
            anonymous: false
        }).then((user) => {
            if (!user) {
                return null;
            }
            return password_token_model_1.PasswordTokenModel.findOneAndUpdate({
                userId: user.id
            }, {
                $set: {
                    token,
                    used: false
                }
            }, {
                upsert: true
            }).exec()
                .then(() => user);
        });
    }
    updatePassword(token, password) {
        // bug similar to https://github.com/Automattic/mongoose/issues/1618
        // findOneAndDelete() does not return removed doc *sometimes*
        return password_token_model_1.PasswordTokenModel.findOneAndUpdate({
            token,
            used: false
        }, {
            $set: { used: true }
        }).exec().then((passwordTokenDoc) => {
            if (!passwordTokenDoc) {
                return null;
            }
            return user_model_1.UserModel.findOneAndUpdate({
                _id: passwordTokenDoc.userId
            }, {
                $set: {
                    password
                }
            }).exec();
        });
    }
}
exports.AuthRepo = AuthRepo;
