"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Project: ngrx-quiz-api (https://github.com/pmstss/ngrx-quiz-api)
 * Copyright 2019 Viachaslau Tyshkavets
 * Licensed under the GPLv3 License. See LICENSE.txt in the project root for license information.
 */
const mongoose = require("mongoose");
const bcrypt_1 = require("bcrypt");
const consts_1 = require("../../consts/consts");
// tslint:disable-next-line variable-name
const UserSchema = new mongoose.Schema({
    fullName: {
        type: mongoose.SchemaTypes.String,
        maxlength: 64,
        minlength: 5,
        trim: true,
        required: true
    },
    email: {
        type: mongoose.SchemaTypes.String,
        trim: true,
        minlength: 6,
        maxlength: 64,
        required: true,
        index: {
            unique: true
        }
    },
    password: {
        type: mongoose.SchemaTypes.String,
        trim: true,
        minlength: 8,
        maxlength: 64,
        required: true
    },
    admin: {
        type: mongoose.SchemaTypes.Boolean,
        required: true,
        default: false
    },
    social: {
        type: mongoose.SchemaTypes.String,
        trim: true,
        maxlength: 10,
        required: false
    },
    anonymous: {
        type: mongoose.SchemaTypes.Boolean,
        required: true,
        default: false
    }
}, {
    timestamps: true
});
function hashPassword(pass) {
    return bcrypt_1.hashSync(pass, consts_1.SALT_ROUNDS);
}
exports.hashPassword = hashPassword;
UserSchema.pre('save', function (next) {
    this.set('password', hashPassword(this.get('password')));
    next();
});
UserSchema.pre('findOneAndUpdate', function (next) {
    this.update({}, { password: hashPassword(this.getUpdate().$set.password) });
    next();
});
// tslint:disable-next-line variable-name
exports.UserModel = mongoose.model('User', UserSchema);
