"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Project: ngrx-quiz-api (https://github.com/pmstss/ngrx-quiz-api)
 * Copyright 2019 Viachaslau Tyshkavets
 * Licensed under the GPLv3 License. See LICENSE.txt in the project root for license information.
 */
const mongoose = require("mongoose");
const item_comment_model_1 = require("./item-comment-model");
const api_error_1 = require("../../api/api-error");
const consts_1 = require("../../consts/consts");
class CommentRepo {
    aggregateComments(matchQuery, offset = 0) {
        return item_comment_model_1.ItemCommentModel
            .aggregate()
            .match(matchQuery)
            .lookup({
            from: 'users',
            let: { id: '$userId' },
            pipeline: [
                {
                    $match: {
                        $expr: {
                            $eq: ['$_id', '$$id']
                        }
                    }
                },
                {
                    $project: {
                        _id: 0,
                        fullName: 1
                    }
                }
            ],
            as: 'users'
        })
            .unwind('$users')
            .replaceRoot({
            $mergeObjects: ['$users', '$$ROOT']
        })
            .addFields({
            id: '$_id',
            userName: '$fullName'
        })
            .sort({ createdAt: -1 })
            .skip(offset)
            .limit(consts_1.COMMENTS_PER_PAGE)
            .project({
            userId: 0,
            itemId: 0,
            users: 0,
            fullName: 0,
            _id: 0,
            __v: 0
        });
    }
    getComments(itemId, offset) {
        return this.aggregateComments({
            itemId: mongoose.Types.ObjectId(itemId)
        }, offset).exec();
    }
    getComment(id) {
        return this.aggregateComments({
            _id: mongoose.Types.ObjectId(id)
        }).exec().then((res) => {
            if (res.length) {
                return res[0];
            }
            throw new api_error_1.ApiError('No such comment', 404);
        });
    }
    addComment(comment) {
        return item_comment_model_1.ItemCommentModel.create({
            itemId: mongoose.Types.ObjectId(comment.itemId),
            userId: mongoose.Types.ObjectId(comment.userId),
            text: comment.text
        }).then((doc) => this.getComment(doc._id));
    }
}
exports.CommentRepo = CommentRepo;
