"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const api_error_1 = require("../../api/api-error");
const response_writer_1 = require("../../api/response-writer");
const answer_result_helper_1 = require("./answer-result-helper");
class QuizItemController {
    constructor(repo, scoreRepo) {
        this.repo = repo;
        this.scoreRepo = scoreRepo;
    }
    getQuizItems(req, res, next) {
        const quizId = req.query.quizId;
        if (!req.stateService.hasQuizState(quizId)) {
            throw new api_error_1.ApiError('Quiz is not initialized', 409);
        }
        if (!req.stateService.isFinished(quizId)) {
            throw new api_error_1.ApiError('Quiz is not finished', 409);
        }
        return response_writer_1.writeResponse(this.repo.getItems(quizId), req, res, next);
    }
    getItem(req, res, next) {
        return response_writer_1.writeResponse(this.repo.getItem(req.params.itemId)
            .then((item) => {
            if (!req.stateService.hasQuizState(item.quizId)) {
                throw new api_error_1.ApiError('Quiz is not initialized', 409);
            }
            const itemAnswer = req.stateService
                .getItemAnswer(item.quizId, req.params.itemId);
            if (!itemAnswer) {
                return item;
            }
            const choices = itemAnswer.choices || [];
            return Object.assign({}, item, { choices: item.choices.map((itemChoice) => {
                    const choice = choices && choices.find(ch => ch.id === itemChoice.id);
                    return Object.assign({}, itemChoice, choice);
                }) });
        }), req, res, next);
    }
    submitAnswer(req, res, next) {
        const quizId = req.body.quizId;
        const itemId = req.params.itemId;
        const userChoiceIds = req.body.choiceIds;
        if (!userChoiceIds || !quizId || !itemId) {
            return response_writer_1.writeErrorResponse(res, next, new api_error_1.ApiError('Missing required parameters', 422));
        }
        if (!req.stateService.hasQuizState(quizId)) {
            return response_writer_1.writeErrorResponse(res, next, new api_error_1.ApiError('Quiz is not initialized', 409));
        }
        if (req.stateService.isAnswered(quizId, itemId)) {
            return response_writer_1.writeErrorResponse(res, next, new api_error_1.ApiError('Answer is already submitted', 409));
        }
        return response_writer_1.writeResponse(this.repo.submitAnswer(quizId, itemId, userChoiceIds)
            .then((doc) => {
            const answerResult = answer_result_helper_1.AnswerResultHelper.create(userChoiceIds, doc);
            req.stateService.addAnswer(quizId, itemId, answerResult);
            if (req.stateService.isScoreSaveRequired(quizId)) {
                this.scoreRepo.saveScore(req.stateService.getQuizScoreDoc(quizId));
            }
            return answerResult;
        }), req, res, next);
    }
}
exports.QuizItemController = QuizItemController;
