"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Project: ngrx-quiz-api (https://github.com/pmstss/ngrx-quiz-api)
 * Copyright 2019 Viachaslau Tyshkavets
 * Licensed under the GPLv3 License. See LICENSE.txt in the project root for license information.
 */
const mongoose = require("mongoose");
const quiz_item_model_1 = require("./quiz-item-model");
const api_error_1 = require("../../api/api-error");
class QuizItemRepo {
    aggregateItems(matchQuery) {
        return quiz_item_model_1.QuizItemModel
            .aggregate()
            .match(matchQuery)
            .addFields({
            id: '$_id',
            choices: {
                $map: {
                    input: '$choices',
                    as: 'x',
                    in: {
                        id: '$$x._id',
                        text: '$$x.text'
                    }
                }
            }
        })
            .lookup({
            from: 'itemcomments',
            let: { id: '$_id' },
            pipeline: [{
                    $match: {
                        $expr: {
                            $eq: ['$itemId', '$$id']
                        }
                    }
                }],
            as: 'comments'
        })
            .addFields({
            numberOfComments: {
                $size: '$comments'
            }
        })
            .project({
            _id: 0,
            __v: 0,
            comments: 0
        });
    }
    getItem(itemId) {
        return this.aggregateItems({
            _id: mongoose.Types.ObjectId(itemId)
        }).exec().then((res) => {
            if (res.length) {
                return Object.assign({}, res[0], { choices: res[0].choices.map((ch) => (Object.assign({}, ch, { id: ch.id.toHexString() }))) });
            }
            throw new api_error_1.ApiError('No such item', 404);
        });
    }
    getItems(quizId) {
        return this.aggregateItems({
            quizId: mongoose.Types.ObjectId(quizId)
        }).exec().then((res) => {
            if (res.length) {
                return res.map(r => (Object.assign({}, r, { choices: res[0].choices.map((ch) => (Object.assign({}, ch, { id: ch.id.toHexString() }))) })));
            }
            return res;
        });
    }
    submitAnswer(quizId, itemId, choiceIds) {
        const choiceObjectIds = choiceIds.map((id) => mongoose.Types.ObjectId(id));
        return quiz_item_model_1.QuizItemModel.findOneAndUpdate({
            _id: mongoose.Types.ObjectId(itemId),
            quizId: mongoose.Types.ObjectId(quizId)
        }, {
            $inc: {
                'choices.$[element].counter': 1,
                counter: 1
            }
        }, {
            arrayFilters: [{
                    'element._id': {
                        $in: choiceObjectIds
                    }
                }],
            multi: true,
            new: true
        }).exec()
            .then((doc) => (Object.assign({}, doc.toObject(), { choices: doc.choices.map((ch) => ({
                id: ch._id.toHexString(),
                counter: ch.counter,
                text: ch.text,
                explanation: ch.explanation,
                correct: ch.correct
            })) })));
    }
}
exports.QuizItemRepo = QuizItemRepo;
