"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const api_error_1 = require("../../api/api-error");
const quiz_model_1 = require("./quiz-model");
class QuizRepo {
    getQuizList() {
        return quiz_model_1.QuizModel
            .aggregate()
            .match({
            public: true,
            published: true
        })
            .lookup({
            from: 'items',
            localField: '_id',
            foreignField: 'quizId',
            as: 'items'
        })
            .addFields({
            id: '$_id',
            totalQuestions: { $size: '$items' }
        })
            .project({
            _id: 0,
            __v: 0,
            items: 0
        })
            .exec();
    }
    getQuiz(shortName) {
        return quiz_model_1.QuizModel
            .aggregate()
            .match({
            shortName
        })
            .lookup({
            from: 'items',
            localField: '_id',
            foreignField: 'quizId',
            as: 'items'
        })
            .addFields({
            itemIds: {
                $map: {
                    input: '$items',
                    as: 'x',
                    in: '$$x._id'
                }
            },
            id: '$_id'
        })
            .project({
            _id: 0,
            __v: 0,
            items: 0
        })
            .exec()
            .then((res) => {
            if (res.length) {
                return res[0];
            }
            throw new api_error_1.ApiError('No such quiz', 404);
        });
    }
}
exports.QuizRepo = QuizRepo;
