"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const response_writer_1 = require("../../api/response-writer");
const api_error_1 = require("../../api/api-error");
class ScoreController {
    constructor(repo) {
        this.repo = repo;
    }
    getTopScores(req, res, next) {
        return response_writer_1.writeResponse(this.repo.getTopScores(req.params.quizId), req, res, next);
    }
    getQuizScore(req, res, next) {
        const quizId = req.params.quizId;
        if (!req.stateService.hasQuizState(quizId)) {
            throw new api_error_1.ApiError('Quiz is not initialized', 409);
        }
        if (!req.stateService.isFinished(quizId)) {
            throw new api_error_1.ApiError('Quiz is not finished', 409);
        }
        const state = req.stateService.getQuizState(quizId);
        const percentScore = state.score / state.itemIds.length;
        return response_writer_1.writeResponse(this.repo.getQuizPosition(quizId, percentScore).then((quizPosition) => (Object.assign({}, quizPosition, { score: percentScore }))), req, res, next);
    }
    getQuizScoreStats(req, res, next) {
        const quizId = req.params.quizId;
        if (!req.stateService.hasQuizState(quizId)) {
            throw new api_error_1.ApiError('Quiz is not initialized', 409);
        }
        if (!req.stateService.isFinished(quizId)) {
            throw new api_error_1.ApiError('Quiz is not finished', 409);
        }
        return response_writer_1.writeResponse(this.repo.getQuizScoreStats(req.params.quizId, req.stateService.getTotalQuestions(quizId)), req, res, next);
    }
}
exports.ScoreController = ScoreController;
