"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Project: ngrx-quiz-api (https://github.com/pmstss/ngrx-quiz-api)
 * Copyright 2019 Viachaslau Tyshkavets
 * Licensed under the GPLv3 License. See LICENSE.txt in the project root for license information.
 */
const consts_1 = require("../consts/consts");
const nodemailer = require('nodemailer'); // @types are outdated
// TODO improve with https://github.com/wildbit/postmark-templates
const resetMailTemplate = (username, url) => {
    return `
<h1>Hello ${username},</h1>
<p>You recently requested to reset your password for your <a href="https://rankme.pro">rankme.pro</a> account.</p>
<p>Please use following link to reset it: <a href="${url}">${url}</a>.</p>
<p><strong>This password reset is only valid for the next 24 hours.</strong></p>
<br>
<p>If you did not request a password reset, please ignore this email or
<a href="mailto:admin@rankme.pro">contact support</a> if you have questions.</p>
<br>
Thanks,
rankme.pro Administration
`;
};
class Mailer {
    constructor() {
        this.transporter = nodemailer.createTransport({
            host: consts_1.MAIL_HOST,
            port: consts_1.MAIL_PORT,
            secure: false,
            auth: {
                user: consts_1.MAIL_USER,
                pass: consts_1.MAIL_PASS
            }
        });
    }
    static getInstance() {
        if (!Mailer.instance) {
            Mailer.instance = new Mailer();
        }
        return Mailer.instance;
    }
    verify() {
        return new Promise((resolve, reject) => {
            this.transporter.verify((error, success) => {
                if (error) {
                    reject(error);
                }
                else {
                    resolve(true);
                }
            });
        });
    }
    sendPasswordReset(username, email, token) {
        return new Promise((resolve, reject) => {
            const url = `${consts_1.MAIL_RESET_URL}${token}`;
            this.transporter.sendMail({
                from: consts_1.MAIL_USER,
                to: email,
                subject: 'rankme.pro password recovery',
                text: `Hello, ${username}! Please reset your password here: ${url}`,
                html: resetMailTemplate(username, url)
            }, (error, info) => {
                if (error) {
                    reject(error);
                }
                else {
                    resolve(info);
                }
            });
        });
    }
}
exports.Mailer = Mailer;
