"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Project: ngrx-quiz-api (https://github.com/pmstss/ngrx-quiz-api)
 * Copyright 2019 Viachaslau Tyshkavets
 * Licensed under the GPLv3 License. See LICENSE.txt in the project root for license information.
 */
const express = require("express");
const session = require("express-session");
const morgan = require("morgan");
const bodyParser = require("body-parser");
const cors = require("cors");
const compression = require("compression");
const consts_1 = require("./consts/consts");
const db_1 = require("./db/db");
const mailer_1 = require("./mail/mailer");
const token_guard_1 = require("./token/token-guard");
const state_guard_1 = require("./state/state-guard");
const auth_router_1 = require("./entities/auth/auth-router");
const quiz_router_1 = require("./entities/quiz/quiz-router");
const admin_quiz_router_1 = require("./entities/admin-quiz/admin-quiz-router");
const admin_quiz_item_router_1 = require("./entities/admin-quiz-item/admin-quiz-item-router");
const item_comment_router_1 = require("./entities/item-comment/item-comment-router");
const quiz_item_router_1 = require("./entities/quiz-item/quiz-item-router");
const oauth_router_1 = require("./entities/oauth/oauth-router");
const score_router_1 = require("./entities/score/score-router");
// tslint:disable-next-line variable-name
const MongoStore = require('connect-mongo')(session);
(() => __awaiter(this, void 0, void 0, function* () {
    let connection;
    try {
        connection = yield db_1.dbConnect();
    }
    catch (e) {
        console.error('db connection error', e);
        process.exit(-2);
    }
    try {
        yield mailer_1.Mailer.getInstance().verify();
    }
    catch (e) {
        console.error('SMTP initialization error', e);
    }
    const app = express();
    app.use(compression({ threshold: 256 }));
    if (process.env.NODE_ENV === 'development') {
        app.set('json spaces', 4);
    }
    app.enable('trust proxy'); // for heroku req.protocol
    const corsOrigins = consts_1.CORS_ORIGIN.split(',').map(item => item.trim());
    app.use(cors({
        origin: corsOrigins,
        credentials: true
    }));
    app.use(morgan('dev'));
    app.use(bodyParser.json());
    app.use(session({
        secret: consts_1.COOKIE_SECRET_KEY,
        store: new MongoStore({
            mongooseConnection: connection
        }),
        resave: true,
        saveUninitialized: true,
        proxy: true,
        cookie: {
            httpOnly: true,
            secure: process.env.NODE_ENV !== 'development'
        }
    }));
    app.use('/auth', auth_router_1.authRouter);
    app.use('/oauth', oauth_router_1.oauthRouter);
    app.use('/api/admin/quizes', token_guard_1.tokenGuard, admin_quiz_router_1.adminQuizRouter);
    app.use('/api/admin/items', token_guard_1.tokenGuard, admin_quiz_item_router_1.adminQuizItemRouter);
    app.use('/api/comments', state_guard_1.stateGuard, token_guard_1.tokenGuard, item_comment_router_1.itemCommentRouter);
    app.use('/api/quizes', state_guard_1.stateGuard, quiz_router_1.quizRouter); // tokenGuard is inside router - not for all routes
    app.use('/api/items', state_guard_1.stateGuard, token_guard_1.tokenGuard, quiz_item_router_1.quizItemRouter);
    app.use('/api/scores', state_guard_1.stateGuard, token_guard_1.tokenGuard, score_router_1.quizScoreRouter);
    app.use((req, res) => {
        res.status(404).send('Not found');
    });
    app.use((err, req, res) => {
        res.status(err.status || 500).send(err.message);
    });
    app.listen(consts_1.SERVER_PORT, () => console.log('Listening...'));
}))();
