"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const jsonwebtoken_1 = require("jsonwebtoken");
const consts_1 = require("../consts/consts");
const api_error_1 = require("../api/api-error");
class TokenUtils {
    constructor() {
    }
    static createUserToken(user) {
        return jsonwebtoken_1.sign({
            user: {
                id: user.id,
                fullName: user.fullName,
                email: user.email,
                admin: user.admin,
                anonymous: user.anonymous,
                social: user.social
            }
        }, consts_1.JWT_SECRET_KEY, {
            expiresIn: '1m'
        });
    }
    static parseFromRequest(req) {
        const token = req.headers['authorization'] || req.query.token;
        return token && token.startsWith('Bearer ') ? token.substr('Bearer '.length) : token;
    }
    static verifyCallback(resolve, reject, err, tokenData) {
        if (err) {
            reject(err);
        }
        else {
            if (!tokenData || !tokenData.user) {
                reject(new api_error_1.ApiError('Invalid token format', 422));
            }
            else {
                resolve(tokenData);
            }
        }
    }
    static verify(token) {
        return new Promise((resolve, reject) => {
            jsonwebtoken_1.verify(token, consts_1.JWT_SECRET_KEY, TokenUtils.verifyCallback.bind(TokenUtils, resolve, reject));
        });
    }
    static verifyIgnoringExpiration(token) {
        return new Promise((resolve, reject) => {
            jsonwebtoken_1.verify(token, consts_1.JWT_SECRET_KEY, {
                ignoreExpiration: true
            }, TokenUtils.verifyCallback.bind(TokenUtils, resolve, reject));
        });
    }
}
exports.TokenUtils = TokenUtils;
